package App::pl v0.0.0;		# merge in real version when packaging for CPAN;

use 5.16.0;
use warnings;

warn "This is a just dummy package for CPAN.  Please run the script 'pl' directly!\n";
